@@ -4,7 +4,7 @@ use namespace::autoclean;
 
 use Moo;
 use File::Basename             qw( basename );
-use File::DataClass::Constants;
+use File::DataClass::Constants qw( EXCEPTION_CLASS FALSE NUL TRUE );
 use File::DataClass::Functions qw( is_stale merge_file_data throw );
 use File::DataClass::Types     qw( Object );
 use File::Gettext;
@@ -24,6 +24,118 @@ has 'storage' => is => 'ro',   isa => Object,  required => TRUE,
    handles    => [ qw( extn meta_pack meta_unpack
                        read_file txn_do validate_params ) ];
 
+# Private functions
+my $_get_attributes = sub {
+   my ($condition, $source) = @_;
+
+   return grep { not m{ \A _ }msx
+                 and $_ ne 'id' and $_ ne 'name'
+                 and $condition->( $_ ) } @{ $source->attributes || [] };
+};
+
+# Private methods
+my $_extn = sub {
+   my $extn = (split m{ \. }mx, ($_[ 1 ] || NUL))[ -1 ];
+
+   return $extn ? ".${extn}" : $_[ 0 ]->extn;
+};
+
+my $_gettext = sub {
+   my ($self, $path) = @_; $path or throw Unspecified, [ 'path name' ];
+
+   my $gettext = $self->gettext; my $extn = $self->$_extn( $path );
+
+   $gettext->set_path( $self->lang, basename( "${path}", $extn ) );
+
+   return $gettext;
+};
+
+my $_create_or_update = sub {
+   my ($self, $path, $result, $updating) = @_;
+
+   my $source    = $result->can( 'result_source' )
+                 ? $result->result_source : $result->_resultset->source;
+   my $condition = sub { not $source->lang_dep->{ $_[ 0 ] } };
+   my $updated   = $self->storage->create_or_update
+      ( $path, $result, $updating, $condition );
+   my $rs        = $self->$_gettext( $path )->resultset;
+   my $element   = $source->name;
+
+   $condition = sub { $source->lang_dep->{ $_[ 0 ] } };
+
+   for my $attr_name ($_get_attributes->( $condition, $source )) {
+      my $msgstr = $result->$attr_name() or next;
+      my $attrs  = { msgctxt => "${element}.${attr_name}",
+                     msgid   => $result->name,
+                     msgstr  => [ $msgstr ], };
+
+      $attrs->{name} = $rs->storage->make_key( $attrs ); my $name;
+
+      try {
+         $name = $updating ? $rs->create_or_update( $attrs )
+                           : $rs->create( $attrs );
+      }
+      catch { $_->class ne NothingUpdated and throw $_ };
+
+      $updated ||= $name ? TRUE : FALSE;
+   }
+
+   $updating and not $updated and throw NothingUpdated, level => 4;
+   $updated  and $path->touch;
+   return $updated;
+};
+
+my $_get_key_and_newest = sub {
+   my ($self, $paths) = @_; my $key; my $newest = 0; my $valid = TRUE;
+
+   for my $path (grep { length } map { "${_}" } @{ $paths }) {
+      $key .= $key ? "~${path}" : $path;
+
+      my $mtime = $self->cache->get_mtime( $path );
+
+      if ($mtime) { $mtime > $newest and $newest = $mtime }
+      else { $valid = FALSE }
+
+      my $file      = basename( "${path}", $self->$_extn( $path ) );
+      my $lang_path = $self->gettext->get_path( $self->lang, $file );
+
+      if (defined ($mtime = $self->cache->get_mtime( "${lang_path}" ))) {
+         if ($mtime) {
+            $key .= $key ? "~${lang_path}" : $lang_path;
+            $mtime > $newest and $newest = $mtime;
+         }
+      }
+      else {
+         if (-f $lang_path) {
+            $key .= $key ? "~${lang_path}" : $lang_path; $valid = FALSE;
+         }
+         else { $self->cache->set_mtime( "${lang_path}", 0 ) }
+      }
+   }
+
+   return ($key, $valid ? $newest : undef);
+};
+
+my $_load_gettext = sub {
+   my ($self, $data, $path) = @_;
+
+   my $gettext = $self->$_gettext( $path ); $gettext->path->is_file or return;
+
+   my $gettext_data = $gettext->load->{ $gettext->source_name };
+
+   for my $key (keys %{ $gettext_data }) {
+      my ($msgctxt, $msgid)     = $gettext->storage->decompose_key( $key );
+      my ($element, $attr_name) = split m{ [\.] }msx, $msgctxt, 2;
+
+      ($element and $attr_name and $msgid) or next;
+
+      $data->{ $element }->{ $msgid }->{ $attr_name }
+         = $gettext_data->{ $key }->{msgstr}->[ 0 ];
+   }
+
+   return $gettext->path->stat->{mtime};
+};
+
 # Public methods
 sub delete {
    my ($self, $path, $result) = @_;
@@ -32,10 +144,10 @@ sub delete {
                  ? $result->result_source : $result->_resultset->source;
    my $condition = sub { $source->lang_dep->{ $_[ 0 ] } };
    my $deleted   = $self->storage->delete( $path, $result );
-   my $rs        = $self->_gettext( $path )->resultset;
+   my $rs        = $self->$_gettext( $path )->resultset;
    my $element   = $source->name;
 
-   for my $attr_name (__get_attributes( $condition, $source )) {
+   for my $attr_name ($_get_attributes->( $condition, $source )) {
       my $attrs  = { msgctxt => "${element}.${attr_name}",
                      msgid   => $result->name, };
       my $name   = $rs->storage->make_key( $attrs );
@@ -50,7 +162,7 @@ sub delete {
 sub dump {
    my ($self, $path, $data) = @_; $self->validate_params( $path, TRUE );
 
-   my $gettext      = $self->_gettext( $path );
+   my $gettext      = $self->$_gettext( $path );
    my $gettext_data = $gettext->path->is_file ? $gettext->load : {};
 
    for my $source (values %{ $self->schema->source_registrations }) {
@@ -76,13 +188,13 @@ sub dump {
 }
 
 sub insert {
-   return $_[ 0 ]->_create_or_update( $_[ 1 ], $_[ 2 ], FALSE );
+   return $_[ 0 ]->$_create_or_update( $_[ 1 ], $_[ 2 ], FALSE );
 }
 
 sub load {
    my ($self, @paths) = @_; $paths[ 0 ] or return {};
 
-   my ($key, $newest) = $self->_get_key_and_newest( \@paths );
+   my ($key, $newest) = $self->$_get_key_and_newest( \@paths );
    my ($data, $meta)  = $self->cache->get( $key );
    my $cache_mtime    = $self->meta_unpack( $meta );
 
@@ -95,7 +207,7 @@ sub load {
 
       merge_file_data $data, $red;
       $path_mtime > $newest and $newest = $path_mtime;
-      $path_mtime = $self->_load_gettext( $data, $path );
+      $path_mtime = $self->$_load_gettext( $data, $path );
       $path_mtime and $path_mtime > $newest and $newest = $path_mtime;
    }
 
@@ -113,121 +225,7 @@ sub select {
 }
 
 sub update {
-   return $_[ 0 ]->_create_or_update( $_[ 1 ], $_[ 2 ], TRUE );
-}
-
-# Private methods
-sub _create_or_update {
-   my ($self, $path, $result, $updating) = @_;
-
-   my $source    = $result->can( 'result_source' )
-                 ? $result->result_source : $result->_resultset->source;
-   my $condition = sub { not $source->lang_dep->{ $_[ 0 ] } };
-   my $updated   = $self->storage->create_or_update
-      ( $path, $result, $updating, $condition );
-   my $rs        = $self->_gettext( $path )->resultset;
-   my $element   = $source->name;
-
-   $condition = sub { $source->lang_dep->{ $_[ 0 ] } };
-
-   for my $attr_name (__get_attributes( $condition, $source )) {
-      my $msgstr = $result->$attr_name() or next;
-      my $attrs  = { msgctxt => "${element}.${attr_name}",
-                     msgid   => $result->name,
-                     msgstr  => [ $msgstr ], };
-
-      $attrs->{name} = $rs->storage->make_key( $attrs ); my $name;
-
-      try {
-         $name = $updating ? $rs->create_or_update( $attrs )
-                           : $rs->create( $attrs );
-      }
-      catch { $_->class ne NothingUpdated and throw $_ };
-
-      $updated ||= $name ? TRUE : FALSE;
-   }
-
-   $updating and not $updated and throw class => NothingUpdated, level => 4;
-   $updated  and $path->touch;
-   return $updated;
-}
-
-sub _extn {
-   my $extn = (split m{ \. }mx, ($_[ 1 ] || NUL))[ -1 ];
-
-   return $extn ? ".${extn}" : $_[ 0 ]->extn;
-}
-
-sub _get_key_and_newest {
-   my ($self, $paths) = @_; my $key; my $newest = 0; my $valid = TRUE;
-
-   for my $path (grep { length } map { "${_}" } @{ $paths }) {
-      $key .= $key ? "~${path}" : $path;
-
-      my $mtime = $self->cache->get_mtime( $path );
-
-      if ($mtime) { $mtime > $newest and $newest = $mtime }
-      else { $valid = FALSE }
-
-      my $file      = basename( "${path}", $self->_extn( $path ) );
-      my $lang_path = $self->gettext->get_path( $self->lang, $file );
-
-      if (defined ($mtime = $self->cache->get_mtime( "${lang_path}" ))) {
-         if ($mtime) {
-            $key .= $key ? "~${lang_path}" : $lang_path;
-            $mtime > $newest and $newest = $mtime;
-         }
-      }
-      else {
-         if (-f $lang_path) {
-            $key .= $key ? "~${lang_path}" : $lang_path; $valid = FALSE;
-         }
-         else { $self->cache->set_mtime( "${lang_path}", 0 ) }
-      }
-   }
-
-   return ($key, $valid ? $newest : undef);
-}
-
-sub _gettext {
-   my ($self, $path) = @_; my $gettext = $self->gettext;
-
-   $path or throw class => Unspecified, args => [ 'path name' ];
-
-   my $extn = $self->_extn( $path );
-
-   $gettext->set_path( $self->lang, basename( "${path}", $extn ) );
-
-   return $gettext;
-}
-
-sub _load_gettext {
-   my ($self, $data, $path) = @_;
-
-   my $gettext = $self->_gettext( $path ); $gettext->path->is_file or return;
-
-   my $gettext_data = $gettext->load->{ $gettext->source_name };
-
-   for my $key (keys %{ $gettext_data }) {
-      my ($msgctxt, $msgid)     = $gettext->storage->decompose_key( $key );
-      my ($element, $attr_name) = split m{ [\.] }msx, $msgctxt, 2;
-
-      ($element and $attr_name and $msgid) or next;
-
-      $data->{ $element }->{ $msgid }->{ $attr_name }
-         = $gettext_data->{ $key }->{msgstr}->[ 0 ];
-   }
-
-   return $gettext->path->stat->{mtime};
-}
-
-# Private functions
-sub __get_attributes {
-   my ($condition, $source) = @_;
-
-   return grep { not m{ \A _ }msx
-                 and $_ ne 'id' and $_ ne 'name'
-                 and $condition->( $_ ) } @{ $source->attributes || [] };
+   return $_[ 0 ]->$_create_or_update( $_[ 1 ], $_[ 2 ], TRUE );
 }
 
 1;
